==> libkgapi-18.12.3-1-x86_64.pkg.tar.xz: usr/include/KPim/KGAPI/kgapi/drive/permissionfetchjob.h <==
/*
 * This file is part of LibKGAPI library
 *
 * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef KGAPI2_DRIVEPERMISSIONFETCHJOB_H
#define KGAPI2_DRIVEPERMISSIONFETCHJOB_H

#include "fetchjob.h"
#include "kgapidrive_export.h"

namespace KGAPI2
{

namespace Drive
{

class KGAPIDRIVE_EXPORT PermissionFetchJob : public KGAPI2::FetchJob
{

    Q_OBJECT

  public:
    explicit PermissionFetchJob(const QString &fileId, const AccountPtr &account,
                                QObject *parent = nullptr);
    explicit PermissionFetchJob(const FilePtr &file, const AccountPtr &account,
                                QObject *parent = nullptr);
    explicit PermissionFetchJob(const QString &fileId, const QString &permissionId,
                                const AccountPtr &account, QObject *parent = nullptr);
    explicit PermissionFetchJob(const FilePtr &file, const QString &permissionId,
                                const AccountPtr &account, QObject *parent = nullptr);
    ~PermissionFetchJob() override;

  protected:
    void start() override;
    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
            const QByteArray &rawData) override;

  private:
    class Private;
    Private *const d;
    friend class Private;
};

} // namespace Drive

} // namespace KGAPI2

#endif // KGAPI2_DRIVEPERMISSIONFETCHJOB_H

==> libkgapi-19.07.90-1-x86_64.pkg.tar.xz: usr/include/KPim/KGAPI/kgapi/drive/permissionfetchjob.h <==
/*
 * This file is part of LibKGAPI library
 *
 * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef KGAPI2_DRIVEPERMISSIONFETCHJOB_H
#define KGAPI2_DRIVEPERMISSIONFETCHJOB_H

#include "fetchjob.h"
#include "kgapidrive_export.h"

namespace KGAPI2
{

namespace Drive
{

class KGAPIDRIVE_EXPORT PermissionFetchJob : public KGAPI2::FetchJob
{

    Q_OBJECT

  public:
    explicit PermissionFetchJob(const QString &fileId, const AccountPtr &account,
                                QObject *parent = nullptr);
    explicit PermissionFetchJob(const FilePtr &file, const AccountPtr &account,
                                QObject *parent = nullptr);
    explicit PermissionFetchJob(const QString &fileId, const QString &permissionId,
                                const AccountPtr &account, QObject *parent = nullptr);
    explicit PermissionFetchJob(const FilePtr &file, const QString &permissionId,
                                const AccountPtr &account, QObject *parent = nullptr);
    ~PermissionFetchJob() override;

    /**
     * @brief Whether the request supports both My Drives and shared drives.
     *
     * Set to true by default as LibKGAPI supports Team Drives.
     *
     * @deprecated This parameter will only be effective until June 1, 2020. Afterwards all applications
     * are assumed to support shared drives.
     */
    KGAPIDRIVE_DEPRECATED bool supportsAllDrives() const;

    /**
     * @brief Sets whether the request supports both My Drives and shared drives.
     *
     * Set to true by default as LibKGAPI supports Team Drives.
     *
     * @deprecated This parameter will only be effective until June 1, 2020. Afterwards all applications
     * are assumed to support shared drives.
     */
    KGAPIDRIVE_DEPRECATED void setSupportsAllDrives(bool supportsAllDrives);

  protected:
    void start() override;
    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
            const QByteArray &rawData) override;

  private:
    class Private;
    Private *const d;
    friend class Private;
};

} // namespace Drive

} // namespace KGAPI2

#endif // KGAPI2_DRIVEPERMISSIONFETCHJOB_H
